# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cost/v1/cost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import account_pb2 as api_dot_account__pb2
from alphausblue.api import operation_pb2 as api_dot_operation__pb2
from alphausblue.api import budget_pb2 as api_dot_budget__pb2
from alphausblue.api import forecast_pb2 as api_dot_forecast__pb2
from alphausblue.api.aws import cost_pb2 as api_dot_aws_dot_cost__pb2
from alphausblue.api.aws import calculator_pb2 as api_dot_aws_dot_calculator__pb2
from alphausblue.api.aws import recommendation_pb2 as api_dot_aws_dot_recommendation__pb2
from alphausblue.api.aws import reduction_pb2 as api_dot_aws_dot_reduction__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cost/v1/cost.proto',
  package='blueapi.cost.v1',
  syntax='proto3',
  serialized_options=b'\n\026cloud.alphaus.api.costB\tCostProtoZ#github.com/alphauslabs/blueapi/cost\222A\260\002\022\316\001\n\032Alphaus Blue: Cost Service\"R\n\032Alphaus Blue: Cost Service\0224https://alphauslabs.github.io/blueapi/apis/cost.html*W\n\033License: Apache License 2.0\0228https://github.com/alphauslabs/blueapi/blob/main/LICENSE2\0031.0r]\n%More about Alphaus Blue: Cost Service\0224https://alphauslabs.github.io/blueapi/apis/cost.html',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x63ost/v1/cost.proto\x12\x0f\x62lueapi.cost.v1\x1a\x11\x61pi/account.proto\x1a\x13\x61pi/operation.proto\x1a\x10\x61pi/budget.proto\x1a\x12\x61pi/forecast.proto\x1a\x12\x61pi/aws/cost.proto\x1a\x18\x61pi/aws/calculator.proto\x1a\x1c\x61pi/aws/recommendation.proto\x1a\x17\x61pi/aws/reduction.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"*\n\x18ListPayerAccountsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\"4\n\x16GetPayerAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"P\n#GetPayerAccountImportHistoryRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05month\x18\x03 \x01(\t\"U\n$GetPayerAccountImportHistoryResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05month\x18\x02 \x01(\t\x12\x12\n\ntimestamps\x18\x03 \x03(\t\"\x88\x01\n#CreatePayerAccountRequestAwsOptions\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nbucketName\x18\x03 \x01(\t\x12\x0e\n\x06prefix\x18\x04 \x01(\t\x12\x12\n\nreportName\x18\x05 \x01(\t\x12\x0f\n\x07roleArn\x18\x06 \x01(\t\"u\n\x19\x43reatePayerAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12H\n\nawsOptions\x18\x02 \x01(\x0b\x32\x34.blueapi.cost.v1.CreatePayerAccountRequestAwsOptions\"7\n\x19\x44\x65letePayerAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"%\n\x13ListAccountsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\"/\n\x11GetAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"=\n\x1e\x43reateAccountRequestAwsOptions\x12\x1b\n\x13managementAccountId\x18\x01 \x01(\t\"\x95\x01\n\x14\x43reateAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\x43\n\nawsOptions\x18\x05 \x01(\x0b\x32/.blueapi.cost.v1.CreateAccountRequestAwsOptions\"2\n\x14\x44\x65leteAccountRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\";\n\x1aGetCalculatorStatusRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05month\x18\x02 \x01(\t\"\x9f\x01\n\x1bGetCalculatorStatusResponse\x12\x43\n\x03\x61ws\x18\x01 \x01(\x0b\x32\x36.blueapi.cost.v1.GetCalculatorStatusResponse.AwsStatus\x1a;\n\tAwsStatus\x12\x15\n\rlastCompleted\x18\x01 \x01(\t\x12\x17\n\x0f\x63urrentProgress\x18\x02 \x01(\x01\",\n\x1aGetCalculatorConfigRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\"M\n\x1bGetCalculatorConfigResponse\x12.\n\x03\x61ws\x18\x01 \x01(\x0b\x32!.blueapi.api.aws.CalculatorConfig\"6\n\x15ImportCurFilesRequest\x12\r\n\x05month\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\".\n\x08\x43ostItem\x12\"\n\x03\x61ws\x18\x01 \x01(\x0b\x32\x15.blueapi.api.aws.Cost\"X\n\x1f\x43\x61lculateCostsRequestAwsOptions\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x12\x14\n\x0c\x61\x63\x63ountsOnly\x18\x02 \x01(\x08\x12\x10\n\x08tagsOnly\x18\x03 \x01(\x08\"\x8d\x01\n\x15\x43\x61lculateCostsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\r\n\x05month\x18\x03 \x01(\t\x12\x44\n\nawsOptions\x18\x04 \x01(\x0b\x32\x30.blueapi.cost.v1.CalculateCostsRequestAwsOptions\"S\n\x1eListCalculationsHistoryRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0c\n\x04\x61sOf\x18\x02 \x01(\t\x12\x13\n\x0b\x65xcludeDone\x18\x03 \x01(\x08\"P\n\"ListCalculationsHistoryAwsResponse\x12*\n\noperations\x18\x01 \x03(\x0b\x32\x16.blueapi.api.Operation\"c\n\x1fListCalculationsHistoryResponse\x12@\n\x03\x61ws\x18\x01 \x01(\x0b\x32\x33.blueapi.cost.v1.ListCalculationsHistoryAwsResponse\"\xae\x01\n!ReadCostsRequestAwsOptionsFilters\x12V\n\nandFilters\x18\x01 \x03(\x0b\x32\x42.blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.AndFiltersEntry\x1a\x31\n\x0f\x41ndFiltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x01\n\x1aReadCostsRequestAwsOptions\x12\x16\n\x0egroupByColumns\x18\x01 \x01(\t\x12\x14\n\x0cgroupByMonth\x18\x02 \x01(\x08\x12\x43\n\x07\x66ilters\x18\x03 \x03(\x0b\x32\x32.blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters\x12\x13\n\x0bincludeTags\x18\x04 \x01(\x08\x12\x1d\n\x15includeCostCategories\x18\x05 \x01(\x08\x12\x12\n\ntoCurrency\x18\x06 \x01(\t\x12\x13\n\x0b\x66orceLatest\x18\x07 \x01(\x08\"\xab\x01\n\x10ReadCostsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\x11\n\taccountId\x18\x03 \x01(\t\x12\x11\n\tstartTime\x18\x04 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x05 \x01(\t\x12?\n\nawsOptions\x18\x06 \x01(\x0b\x32+.blueapi.cost.v1.ReadCostsRequestAwsOptions\"6\n ReadAdjustmentsRequestAwsOptions\x12\x12\n\ntoCurrency\x18\x01 \x01(\t\"\xb7\x01\n\x16ReadAdjustmentsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\x11\n\taccountId\x18\x03 \x01(\t\x12\x11\n\tstartTime\x18\x04 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x05 \x01(\t\x12\x45\n\nawsOptions\x18\x06 \x01(\x0b\x32\x31.blueapi.cost.v1.ReadAdjustmentsRequestAwsOptions\".\n\x1dReadTagCostsRequestAwsOptions\x12\r\n\x05tagId\x18\x01 \x01(\t\"\xbf\x01\n\x13ReadTagCostsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x19\n\x11\x62illingInternalId\x18\x02 \x01(\t\x12\x11\n\tstartTime\x18\x03 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\t\x12\x15\n\rgroupByMonths\x18\x05 \x01(\x08\x12\x42\n\nawsOptions\x18\x06 \x01(\x0b\x32..blueapi.cost.v1.ReadTagCostsRequestAwsOptions\"~\n\x16ReadNonTagCostsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x19\n\x11\x62illingInternalId\x18\x02 \x01(\t\x12\x11\n\tstartTime\x18\x03 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\t\x12\x15\n\rgroupByMonths\x18\x05 \x01(\x08\"|\n\x13GetForecastsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x11\n\tcompanyId\x18\x02 \x01(\t\x12\x11\n\tfrequency\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x10\n\x08\x66romDate\x18\x05 \x01(\t\x12\x0e\n\x06toDate\x18\x06 \x01(\t\"G\n\x14GetForecastsResponse\x12/\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32!.blueapi.api.BillingGroupForecast\"l\n\x1dGetMonthlyCostForecastRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08\x66romDate\x18\x04 \x01(\t\x12\x0e\n\x06toDate\x18\x05 \x01(\t\"o\n\x1eGetMonthlyCostForecastResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .blueapi.api.MonthlyCostForecast\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"]\n\"GetMonthOnMonthCostForecastRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\"y\n#GetMonthOnMonthCostForecastResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.blueapi.api.MonthOnMonthCostForecast\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"\\\n!GetMonthToDateCostForecastRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\"\x87\x01\n\"GetMonthToDateCostForecastResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x62udget\x18\x02 \x01(\x01\x12\x32\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32$.blueapi.api.MonthToDateCostForecast\x12\x11\n\ttimestamp\x18\x04 \x01(\t\"R\n\x17GetAccountBudgetRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04year\x18\x04 \x01(\t\"=\n\x18GetAccountBudgetResponse\x12!\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x13.blueapi.api.Budget\"j\n\x1a\x43reateAccountBudgetRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12!\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x13.blueapi.api.Budget\"/\n\x1b\x43reateAccountBudgetResponse\x12\x10\n\x08\x62udgetId\x18\x01 \x01(\t\"a\n\x1aUpdateAccountBudgetRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x10\n\x08\x62udgetId\x18\x02 \x01(\t\x12!\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x13.blueapi.api.Budget\">\n\x1a\x44\x65leteAccountBudgetRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x10\n\x08\x62udgetId\x18\x02 \x01(\t\"\x80\x02\n#GetRecommendationsRequestAwsOptions\x12\x1a\n\x12recommendationType\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\nriServices\x18\x03 \x03(\t\x12\x12\n\nspServices\x18\x04 \x03(\t\x12\x1e\n\x16purchaseEC2SavingsPlan\x18\x05 \x01(\x08\x12\x0c\n\x04term\x18\x06 \x01(\t\x12\x15\n\rofferingClass\x18\x07 \x01(\t\x12\x15\n\rpaymentOption\x18\x08 \x01(\t\x12\x0f\n\x07tenancy\x18\t \x01(\t\x12\x1a\n\x12\x63overagePercentage\x18\n \x01(\x01\"\x96\x01\n\x19GetRecommendationsRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05orgId\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63\x63ounts\x18\x03 \x03(\t\x12H\n\nawsOptions\x18\x04 \x01(\x0b\x32\x34.blueapi.cost.v1.GetRecommendationsRequestAwsOptions\"l\n\x1aGetRecommendationsResponse\x12\r\n\x05orgId\x18\x01 \x01(\t\x12?\n\x12\x61wsRecommendations\x18\x02 \x01(\x0b\x32#.blueapi.api.aws.AwsRecommendations\"\xcd\x01\n\x17GetCostReductionRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05orgId\x18\x02 \x01(\t\x12\x18\n\x10reductionDisplay\x18\x03 \x01(\t\x12\x10\n\x08\x66romDate\x18\x04 \x01(\t\x12\x0e\n\x06toDate\x18\x05 \x01(\t\x12\x0f\n\x07payerId\x18\x06 \x01(\t\x12\x11\n\tcompanyId\x18\x07 \x01(\t\x12\x0f\n\x07groupId\x18\x08 \x01(\t\x12\x10\n\x08\x61\x63\x63ounts\x18\t \x03(\t\x12\x10\n\x08services\x18\n \x03(\t\"h\n\x18GetCostReductionResponse\x12\r\n\x05orgId\x18\x01 \x01(\t\x12=\n\x11\x61wsCostReductions\x18\x02 \x01(\x0b\x32\".blueapi.api.aws.AwsCostReductions2\xef\x1f\n\x04\x43ost\x12s\n\x11ListPayerAccounts\x12).blueapi.cost.v1.ListPayerAccountsRequest\x1a\x14.blueapi.api.Account\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/{vendor}/payers0\x01\x12r\n\x0fGetPayerAccount\x12\'.blueapi.cost.v1.GetPayerAccountRequest\x1a\x14.blueapi.api.Account\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{vendor}/payers/{id}\x12\xbd\x01\n\x1cGetPayerAccountImportHistory\x12\x34.blueapi.cost.v1.GetPayerAccountImportHistoryRequest\x1a\x35.blueapi.cost.v1.GetPayerAccountImportHistoryResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/{vendor}/payers/{id}/importhistory0\x01\x12v\n\x12\x43reatePayerAccount\x12*.blueapi.cost.v1.CreatePayerAccountRequest\x1a\x14.blueapi.api.Account\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/{vendor}/payers:\x01*\x12z\n\x12\x44\x65letePayerAccount\x12*.blueapi.cost.v1.DeletePayerAccountRequest\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a*\x18/v1/{vendor}/payers/{id}\x12k\n\x0cListAccounts\x12$.blueapi.cost.v1.ListAccountsRequest\x1a\x14.blueapi.api.Account\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{vendor}/accounts0\x01\x12j\n\nGetAccount\x12\".blueapi.cost.v1.GetAccountRequest\x1a\x14.blueapi.api.Account\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/{vendor}/accounts/{id}\x12n\n\rCreateAccount\x12%.blueapi.cost.v1.CreateAccountRequest\x1a\x14.blueapi.api.Account\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/{vendor}/accounts:\x01*\x12r\n\rDeleteAccount\x12%.blueapi.cost.v1.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{vendor}/accounts/{id}\x12\x98\x01\n\x13GetCalculatorStatus\x12+.blueapi.cost.v1.GetCalculatorStatusRequest\x1a,.blueapi.cost.v1.GetCalculatorStatusResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{vendor}/calculator/status\x12\x98\x01\n\x13GetCalculatorConfig\x12+.blueapi.cost.v1.GetCalculatorConfigRequest\x1a,.blueapi.cost.v1.GetCalculatorConfigResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{vendor}/calculator/config\x12o\n\x0eImportCurFiles\x12&.blueapi.cost.v1.ImportCurFilesRequest\x1a\x16.blueapi.api.Operation\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/aws/cur:import:\x01*\x12y\n\x0e\x43\x61lculateCosts\x12&.blueapi.cost.v1.CalculateCostsRequest\x1a\x16.blueapi.api.Operation\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/{vendor}/costs:calculate:\x01*\x12\xa7\x01\n\x17ListCalculationsHistory\x12/.blueapi.cost.v1.ListCalculationsHistoryRequest\x1a\x30.blueapi.cost.v1.ListCalculationsHistoryResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/{vendor}/calculations/history\x12o\n\tReadCosts\x12!.blueapi.cost.v1.ReadCostsRequest\x1a\x19.blueapi.cost.v1.CostItem\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/{vendor}/costs:read:\x01*0\x01\x12\x81\x01\n\x0fReadAdjustments\x12\'.blueapi.cost.v1.ReadAdjustmentsRequest\x1a\x19.blueapi.cost.v1.CostItem\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/{vendor}/adjustments:read:\x01*0\x01\x12x\n\x0cReadTagCosts\x12$.blueapi.cost.v1.ReadTagCostsRequest\x1a\x19.blueapi.cost.v1.CostItem\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/{vendor}/tagcosts:read:\x01*0\x01\x12\x81\x01\n\x0fReadNonTagCosts\x12\'.blueapi.cost.v1.ReadNonTagCostsRequest\x1a\x19.blueapi.cost.v1.CostItem\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/{vendor}/nontagcosts:read:\x01*0\x01\x12{\n\x0cGetForecasts\x12$.blueapi.cost.v1.GetForecastsRequest\x1a%.blueapi.cost.v1.GetForecastsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/{vendor}/forecasts\x12\xae\x01\n\x16GetMonthlyCostForecast\x12..blueapi.cost.v1.GetMonthlyCostForecastRequest\x1a/.blueapi.cost.v1.GetMonthlyCostForecastResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/{vendor}/forecasts/monthly/{level}/{id}\x12\xc4\x01\n\x1bGetMonthOnMonthCostForecast\x12\x33.blueapi.cost.v1.GetMonthOnMonthCostForecastRequest\x1a\x34.blueapi.cost.v1.GetMonthOnMonthCostForecastResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/{vendor}/forecasts/month-on-month/{level}/{id}\x12\xc0\x01\n\x1aGetMonthToDateCostForecast\x12\x32.blueapi.cost.v1.GetMonthToDateCostForecastRequest\x1a\x33.blueapi.cost.v1.GetMonthToDateCostForecastResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/{vendor}/forecasts/month-to-date/{level}/{id}\x12\x91\x01\n\x10GetAccountBudget\x12(.blueapi.cost.v1.GetAccountBudgetRequest\x1a).blueapi.cost.v1.GetAccountBudgetResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{vendor}/budget/{level}/{id}\x12\x9d\x01\n\x13\x43reateAccountBudget\x12+.blueapi.cost.v1.CreateAccountBudgetRequest\x1a,.blueapi.cost.v1.CreateAccountBudgetResponse\"+\x82\xd3\xe4\x93\x02%\" /v1/{vendor}/budget/{level}/{id}:\x01*\x12\x85\x01\n\x13UpdateAccountBudget\x12+.blueapi.cost.v1.UpdateAccountBudgetRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#\x1a\x1e/v1/{vendor}/budget/{budgetId}:\x01*\x12\x82\x01\n\x13\x44\x65leteAccountBudget\x12+.blueapi.cost.v1.DeleteAccountBudgetRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/{vendor}/budget/{budgetId}\x12\xa3\x01\n\x12GetRecommendations\x12*.blueapi.cost.v1.GetRecommendationsRequest\x1a+.blueapi.cost.v1.GetRecommendationsResponse\"4\x82\xd3\xe4\x93\x02.\")/v1/{vendor}/recommendations/{orgId}:read:\x01*\x12\x97\x01\n\x10GetCostReduction\x12(.blueapi.cost.v1.GetCostReductionRequest\x1a).blueapi.cost.v1.GetCostReductionResponse\".\x82\xd3\xe4\x93\x02(\"#/v1/{vendor}/reduction/{orgId}:read:\x01*\x1a\x94\x01\x92\x41\x90\x01\x12@(BETA) Cost API. Base URL: https://api.alphaus.cloud/m/blue/cost\x1aL\n\x12Service definition\x12\x36https://github.com/alphauslabs/blueapi/tree/main/cost/B\xfc\x02\n\x16\x63loud.alphaus.api.costB\tCostProtoZ#github.com/alphauslabs/blueapi/cost\x92\x41\xb0\x02\x12\xce\x01\n\x1a\x41lphaus Blue: Cost Service\"R\n\x1a\x41lphaus Blue: Cost Service\x12\x34https://alphauslabs.github.io/blueapi/apis/cost.html*W\n\x1bLicense: Apache License 2.0\x12\x38https://github.com/alphauslabs/blueapi/blob/main/LICENSE2\x03\x31.0r]\n%More about Alphaus Blue: Cost Service\x12\x34https://alphauslabs.github.io/blueapi/apis/cost.htmlb\x06proto3'
  ,
  dependencies=[api_dot_account__pb2.DESCRIPTOR,api_dot_operation__pb2.DESCRIPTOR,api_dot_budget__pb2.DESCRIPTOR,api_dot_forecast__pb2.DESCRIPTOR,api_dot_aws_dot_cost__pb2.DESCRIPTOR,api_dot_aws_dot_calculator__pb2.DESCRIPTOR,api_dot_aws_dot_recommendation__pb2.DESCRIPTOR,api_dot_aws_dot_reduction__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_LISTPAYERACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListPayerAccountsRequest',
  full_name='blueapi.cost.v1.ListPayerAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ListPayerAccountsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=367,
)


_GETPAYERACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetPayerAccountRequest',
  full_name='blueapi.cost.v1.GetPayerAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetPayerAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetPayerAccountRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=421,
)


_GETPAYERACCOUNTIMPORTHISTORYREQUEST = _descriptor.Descriptor(
  name='GetPayerAccountImportHistoryRequest',
  full_name='blueapi.cost.v1.GetPayerAccountImportHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryRequest.month', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=503,
)


_GETPAYERACCOUNTIMPORTHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetPayerAccountImportHistoryResponse',
  full_name='blueapi.cost.v1.GetPayerAccountImportHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryResponse.month', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='blueapi.cost.v1.GetPayerAccountImportHistoryResponse.timestamps', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=590,
)


_CREATEPAYERACCOUNTREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='CreatePayerAccountRequestAwsOptions',
  full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.bucketName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.prefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reportName', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.reportName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roleArn', full_name='blueapi.cost.v1.CreatePayerAccountRequestAwsOptions.roleArn', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=729,
)


_CREATEPAYERACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreatePayerAccountRequest',
  full_name='blueapi.cost.v1.CreatePayerAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.CreatePayerAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.CreatePayerAccountRequest.awsOptions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=848,
)


_DELETEPAYERACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeletePayerAccountRequest',
  full_name='blueapi.cost.v1.DeletePayerAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.DeletePayerAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.DeletePayerAccountRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=905,
)


_LISTACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListAccountsRequest',
  full_name='blueapi.cost.v1.ListAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ListAccountsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=944,
)


_GETACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetAccountRequest',
  full_name='blueapi.cost.v1.GetAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetAccountRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=946,
  serialized_end=993,
)


_CREATEACCOUNTREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='CreateAccountRequestAwsOptions',
  full_name='blueapi.cost.v1.CreateAccountRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='managementAccountId', full_name='blueapi.cost.v1.CreateAccountRequestAwsOptions.managementAccountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1056,
)


_CREATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateAccountRequest',
  full_name='blueapi.cost.v1.CreateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.CreateAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.CreateAccountRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.cost.v1.CreateAccountRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='blueapi.cost.v1.CreateAccountRequest.parent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.CreateAccountRequest.awsOptions', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1059,
  serialized_end=1208,
)


_DELETEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeleteAccountRequest',
  full_name='blueapi.cost.v1.DeleteAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.DeleteAccountRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.DeleteAccountRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1260,
)


_GETCALCULATORSTATUSREQUEST = _descriptor.Descriptor(
  name='GetCalculatorStatusRequest',
  full_name='blueapi.cost.v1.GetCalculatorStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetCalculatorStatusRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.cost.v1.GetCalculatorStatusRequest.month', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1321,
)


_GETCALCULATORSTATUSRESPONSE_AWSSTATUS = _descriptor.Descriptor(
  name='AwsStatus',
  full_name='blueapi.cost.v1.GetCalculatorStatusResponse.AwsStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastCompleted', full_name='blueapi.cost.v1.GetCalculatorStatusResponse.AwsStatus.lastCompleted', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentProgress', full_name='blueapi.cost.v1.GetCalculatorStatusResponse.AwsStatus.currentProgress', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1483,
)

_GETCALCULATORSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetCalculatorStatusResponse',
  full_name='blueapi.cost.v1.GetCalculatorStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='blueapi.cost.v1.GetCalculatorStatusResponse.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETCALCULATORSTATUSRESPONSE_AWSSTATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1483,
)


_GETCALCULATORCONFIGREQUEST = _descriptor.Descriptor(
  name='GetCalculatorConfigRequest',
  full_name='blueapi.cost.v1.GetCalculatorConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetCalculatorConfigRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1485,
  serialized_end=1529,
)


_GETCALCULATORCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetCalculatorConfigResponse',
  full_name='blueapi.cost.v1.GetCalculatorConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='blueapi.cost.v1.GetCalculatorConfigResponse.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1531,
  serialized_end=1608,
)


_IMPORTCURFILESREQUEST = _descriptor.Descriptor(
  name='ImportCurFilesRequest',
  full_name='blueapi.cost.v1.ImportCurFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.cost.v1.ImportCurFilesRequest.month', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='blueapi.cost.v1.ImportCurFilesRequest.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1664,
)


_COSTITEM = _descriptor.Descriptor(
  name='CostItem',
  full_name='blueapi.cost.v1.CostItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='blueapi.cost.v1.CostItem.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1712,
)


_CALCULATECOSTSREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='CalculateCostsRequestAwsOptions',
  full_name='blueapi.cost.v1.CalculateCostsRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='blueapi.cost.v1.CalculateCostsRequestAwsOptions.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountsOnly', full_name='blueapi.cost.v1.CalculateCostsRequestAwsOptions.accountsOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagsOnly', full_name='blueapi.cost.v1.CalculateCostsRequestAwsOptions.tagsOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1802,
)


_CALCULATECOSTSREQUEST = _descriptor.Descriptor(
  name='CalculateCostsRequest',
  full_name='blueapi.cost.v1.CalculateCostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.CalculateCostsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.cost.v1.CalculateCostsRequest.groupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.cost.v1.CalculateCostsRequest.month', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.CalculateCostsRequest.awsOptions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1946,
)


_LISTCALCULATIONSHISTORYREQUEST = _descriptor.Descriptor(
  name='ListCalculationsHistoryRequest',
  full_name='blueapi.cost.v1.ListCalculationsHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ListCalculationsHistoryRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asOf', full_name='blueapi.cost.v1.ListCalculationsHistoryRequest.asOf', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludeDone', full_name='blueapi.cost.v1.ListCalculationsHistoryRequest.excludeDone', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1948,
  serialized_end=2031,
)


_LISTCALCULATIONSHISTORYAWSRESPONSE = _descriptor.Descriptor(
  name='ListCalculationsHistoryAwsResponse',
  full_name='blueapi.cost.v1.ListCalculationsHistoryAwsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='blueapi.cost.v1.ListCalculationsHistoryAwsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2033,
  serialized_end=2113,
)


_LISTCALCULATIONSHISTORYRESPONSE = _descriptor.Descriptor(
  name='ListCalculationsHistoryResponse',
  full_name='blueapi.cost.v1.ListCalculationsHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='blueapi.cost.v1.ListCalculationsHistoryResponse.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2214,
)


_READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY = _descriptor.Descriptor(
  name='AndFiltersEntry',
  full_name='blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.AndFiltersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.AndFiltersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.AndFiltersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2391,
)

_READCOSTSREQUESTAWSOPTIONSFILTERS = _descriptor.Descriptor(
  name='ReadCostsRequestAwsOptionsFilters',
  full_name='blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='andFilters', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.andFilters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2391,
)


_READCOSTSREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='ReadCostsRequestAwsOptions',
  full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupByColumns', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.groupByColumns', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupByMonth', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.groupByMonth', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.filters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeTags', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.includeTags', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeCostCategories', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.includeCostCategories', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toCurrency', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.toCurrency', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forceLatest', full_name='blueapi.cost.v1.ReadCostsRequestAwsOptions.forceLatest', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2394,
  serialized_end=2630,
)


_READCOSTSREQUEST = _descriptor.Descriptor(
  name='ReadCostsRequest',
  full_name='blueapi.cost.v1.ReadCostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ReadCostsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.cost.v1.ReadCostsRequest.groupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.cost.v1.ReadCostsRequest.accountId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='blueapi.cost.v1.ReadCostsRequest.startTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='blueapi.cost.v1.ReadCostsRequest.endTime', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.ReadCostsRequest.awsOptions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2633,
  serialized_end=2804,
)


_READADJUSTMENTSREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='ReadAdjustmentsRequestAwsOptions',
  full_name='blueapi.cost.v1.ReadAdjustmentsRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='toCurrency', full_name='blueapi.cost.v1.ReadAdjustmentsRequestAwsOptions.toCurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2806,
  serialized_end=2860,
)


_READADJUSTMENTSREQUEST = _descriptor.Descriptor(
  name='ReadAdjustmentsRequest',
  full_name='blueapi.cost.v1.ReadAdjustmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.groupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.accountId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.startTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.endTime', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.ReadAdjustmentsRequest.awsOptions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2863,
  serialized_end=3046,
)


_READTAGCOSTSREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='ReadTagCostsRequestAwsOptions',
  full_name='blueapi.cost.v1.ReadTagCostsRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagId', full_name='blueapi.cost.v1.ReadTagCostsRequestAwsOptions.tagId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3048,
  serialized_end=3094,
)


_READTAGCOSTSREQUEST = _descriptor.Descriptor(
  name='ReadTagCostsRequest',
  full_name='blueapi.cost.v1.ReadTagCostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ReadTagCostsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingInternalId', full_name='blueapi.cost.v1.ReadTagCostsRequest.billingInternalId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='blueapi.cost.v1.ReadTagCostsRequest.startTime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='blueapi.cost.v1.ReadTagCostsRequest.endTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupByMonths', full_name='blueapi.cost.v1.ReadTagCostsRequest.groupByMonths', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.ReadTagCostsRequest.awsOptions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3097,
  serialized_end=3288,
)


_READNONTAGCOSTSREQUEST = _descriptor.Descriptor(
  name='ReadNonTagCostsRequest',
  full_name='blueapi.cost.v1.ReadNonTagCostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.ReadNonTagCostsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingInternalId', full_name='blueapi.cost.v1.ReadNonTagCostsRequest.billingInternalId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='blueapi.cost.v1.ReadNonTagCostsRequest.startTime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='blueapi.cost.v1.ReadNonTagCostsRequest.endTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupByMonths', full_name='blueapi.cost.v1.ReadNonTagCostsRequest.groupByMonths', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3290,
  serialized_end=3416,
)


_GETFORECASTSREQUEST = _descriptor.Descriptor(
  name='GetForecastsRequest',
  full_name='blueapi.cost.v1.GetForecastsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetForecastsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.cost.v1.GetForecastsRequest.companyId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='blueapi.cost.v1.GetForecastsRequest.frequency', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.GetForecastsRequest.level', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromDate', full_name='blueapi.cost.v1.GetForecastsRequest.fromDate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toDate', full_name='blueapi.cost.v1.GetForecastsRequest.toDate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3418,
  serialized_end=3542,
)


_GETFORECASTSRESPONSE = _descriptor.Descriptor(
  name='GetForecastsResponse',
  full_name='blueapi.cost.v1.GetForecastsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.GetForecastsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3544,
  serialized_end=3615,
)


_GETMONTHLYCOSTFORECASTREQUEST = _descriptor.Descriptor(
  name='GetMonthlyCostForecastRequest',
  full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromDate', full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest.fromDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toDate', full_name='blueapi.cost.v1.GetMonthlyCostForecastRequest.toDate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3617,
  serialized_end=3725,
)


_GETMONTHLYCOSTFORECASTRESPONSE = _descriptor.Descriptor(
  name='GetMonthlyCostForecastResponse',
  full_name='blueapi.cost.v1.GetMonthlyCostForecastResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthlyCostForecastResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.GetMonthlyCostForecastResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blueapi.cost.v1.GetMonthlyCostForecastResponse.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=3838,
)


_GETMONTHONMONTHCOSTFORECASTREQUEST = _descriptor.Descriptor(
  name='GetMonthOnMonthCostForecastRequest',
  full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastRequest.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastRequest.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3840,
  serialized_end=3933,
)


_GETMONTHONMONTHCOSTFORECASTRESPONSE = _descriptor.Descriptor(
  name='GetMonthOnMonthCostForecastResponse',
  full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blueapi.cost.v1.GetMonthOnMonthCostForecastResponse.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3935,
  serialized_end=4056,
)


_GETMONTHTODATECOSTFORECASTREQUEST = _descriptor.Descriptor(
  name='GetMonthToDateCostForecastRequest',
  full_name='blueapi.cost.v1.GetMonthToDateCostForecastRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetMonthToDateCostForecastRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.GetMonthToDateCostForecastRequest.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthToDateCostForecastRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.cost.v1.GetMonthToDateCostForecastRequest.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4058,
  serialized_end=4150,
)


_GETMONTHTODATECOSTFORECASTRESPONSE = _descriptor.Descriptor(
  name='GetMonthToDateCostForecastResponse',
  full_name='blueapi.cost.v1.GetMonthToDateCostForecastResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetMonthToDateCostForecastResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='blueapi.cost.v1.GetMonthToDateCostForecastResponse.budget', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.GetMonthToDateCostForecastResponse.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blueapi.cost.v1.GetMonthToDateCostForecastResponse.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4153,
  serialized_end=4288,
)


_GETACCOUNTBUDGETREQUEST = _descriptor.Descriptor(
  name='GetAccountBudgetRequest',
  full_name='blueapi.cost.v1.GetAccountBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetAccountBudgetRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.GetAccountBudgetRequest.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.GetAccountBudgetRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='blueapi.cost.v1.GetAccountBudgetRequest.year', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4290,
  serialized_end=4372,
)


_GETACCOUNTBUDGETRESPONSE = _descriptor.Descriptor(
  name='GetAccountBudgetResponse',
  full_name='blueapi.cost.v1.GetAccountBudgetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.GetAccountBudgetResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4374,
  serialized_end=4435,
)


_CREATEACCOUNTBUDGETREQUEST = _descriptor.Descriptor(
  name='CreateAccountBudgetRequest',
  full_name='blueapi.cost.v1.CreateAccountBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.CreateAccountBudgetRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='blueapi.cost.v1.CreateAccountBudgetRequest.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.cost.v1.CreateAccountBudgetRequest.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.CreateAccountBudgetRequest.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4437,
  serialized_end=4543,
)


_CREATEACCOUNTBUDGETRESPONSE = _descriptor.Descriptor(
  name='CreateAccountBudgetResponse',
  full_name='blueapi.cost.v1.CreateAccountBudgetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='budgetId', full_name='blueapi.cost.v1.CreateAccountBudgetResponse.budgetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4545,
  serialized_end=4592,
)


_UPDATEACCOUNTBUDGETREQUEST = _descriptor.Descriptor(
  name='UpdateAccountBudgetRequest',
  full_name='blueapi.cost.v1.UpdateAccountBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.UpdateAccountBudgetRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budgetId', full_name='blueapi.cost.v1.UpdateAccountBudgetRequest.budgetId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.cost.v1.UpdateAccountBudgetRequest.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4594,
  serialized_end=4691,
)


_DELETEACCOUNTBUDGETREQUEST = _descriptor.Descriptor(
  name='DeleteAccountBudgetRequest',
  full_name='blueapi.cost.v1.DeleteAccountBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.DeleteAccountBudgetRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budgetId', full_name='blueapi.cost.v1.DeleteAccountBudgetRequest.budgetId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4693,
  serialized_end=4755,
)


_GETRECOMMENDATIONSREQUESTAWSOPTIONS = _descriptor.Descriptor(
  name='GetRecommendationsRequestAwsOptions',
  full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommendationType', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.recommendationType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riServices', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.riServices', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spServices', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.spServices', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchaseEC2SavingsPlan', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.purchaseEC2SavingsPlan', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='term', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.term', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offeringClass', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.offeringClass', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paymentOption', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.paymentOption', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenancy', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.tenancy', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coveragePercentage', full_name='blueapi.cost.v1.GetRecommendationsRequestAwsOptions.coveragePercentage', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4758,
  serialized_end=5014,
)


_GETRECOMMENDATIONSREQUEST = _descriptor.Descriptor(
  name='GetRecommendationsRequest',
  full_name='blueapi.cost.v1.GetRecommendationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetRecommendationsRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.cost.v1.GetRecommendationsRequest.orgId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='blueapi.cost.v1.GetRecommendationsRequest.accounts', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsOptions', full_name='blueapi.cost.v1.GetRecommendationsRequest.awsOptions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5017,
  serialized_end=5167,
)


_GETRECOMMENDATIONSRESPONSE = _descriptor.Descriptor(
  name='GetRecommendationsResponse',
  full_name='blueapi.cost.v1.GetRecommendationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.cost.v1.GetRecommendationsResponse.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsRecommendations', full_name='blueapi.cost.v1.GetRecommendationsResponse.awsRecommendations', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5169,
  serialized_end=5277,
)


_GETCOSTREDUCTIONREQUEST = _descriptor.Descriptor(
  name='GetCostReductionRequest',
  full_name='blueapi.cost.v1.GetCostReductionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.cost.v1.GetCostReductionRequest.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.cost.v1.GetCostReductionRequest.orgId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reductionDisplay', full_name='blueapi.cost.v1.GetCostReductionRequest.reductionDisplay', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromDate', full_name='blueapi.cost.v1.GetCostReductionRequest.fromDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toDate', full_name='blueapi.cost.v1.GetCostReductionRequest.toDate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payerId', full_name='blueapi.cost.v1.GetCostReductionRequest.payerId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.cost.v1.GetCostReductionRequest.companyId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.cost.v1.GetCostReductionRequest.groupId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='blueapi.cost.v1.GetCostReductionRequest.accounts', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='services', full_name='blueapi.cost.v1.GetCostReductionRequest.services', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5280,
  serialized_end=5485,
)


_GETCOSTREDUCTIONRESPONSE = _descriptor.Descriptor(
  name='GetCostReductionResponse',
  full_name='blueapi.cost.v1.GetCostReductionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.cost.v1.GetCostReductionResponse.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsCostReductions', full_name='blueapi.cost.v1.GetCostReductionResponse.awsCostReductions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5487,
  serialized_end=5591,
)

_CREATEPAYERACCOUNTREQUEST.fields_by_name['awsOptions'].message_type = _CREATEPAYERACCOUNTREQUESTAWSOPTIONS
_CREATEACCOUNTREQUEST.fields_by_name['awsOptions'].message_type = _CREATEACCOUNTREQUESTAWSOPTIONS
_GETCALCULATORSTATUSRESPONSE_AWSSTATUS.containing_type = _GETCALCULATORSTATUSRESPONSE
_GETCALCULATORSTATUSRESPONSE.fields_by_name['aws'].message_type = _GETCALCULATORSTATUSRESPONSE_AWSSTATUS
_GETCALCULATORCONFIGRESPONSE.fields_by_name['aws'].message_type = api_dot_aws_dot_calculator__pb2._CALCULATORCONFIG
_COSTITEM.fields_by_name['aws'].message_type = api_dot_aws_dot_cost__pb2._COST
_CALCULATECOSTSREQUEST.fields_by_name['awsOptions'].message_type = _CALCULATECOSTSREQUESTAWSOPTIONS
_LISTCALCULATIONSHISTORYAWSRESPONSE.fields_by_name['operations'].message_type = api_dot_operation__pb2._OPERATION
_LISTCALCULATIONSHISTORYRESPONSE.fields_by_name['aws'].message_type = _LISTCALCULATIONSHISTORYAWSRESPONSE
_READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY.containing_type = _READCOSTSREQUESTAWSOPTIONSFILTERS
_READCOSTSREQUESTAWSOPTIONSFILTERS.fields_by_name['andFilters'].message_type = _READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY
_READCOSTSREQUESTAWSOPTIONS.fields_by_name['filters'].message_type = _READCOSTSREQUESTAWSOPTIONSFILTERS
_READCOSTSREQUEST.fields_by_name['awsOptions'].message_type = _READCOSTSREQUESTAWSOPTIONS
_READADJUSTMENTSREQUEST.fields_by_name['awsOptions'].message_type = _READADJUSTMENTSREQUESTAWSOPTIONS
_READTAGCOSTSREQUEST.fields_by_name['awsOptions'].message_type = _READTAGCOSTSREQUESTAWSOPTIONS
_GETFORECASTSRESPONSE.fields_by_name['data'].message_type = api_dot_forecast__pb2._BILLINGGROUPFORECAST
_GETMONTHLYCOSTFORECASTRESPONSE.fields_by_name['data'].message_type = api_dot_forecast__pb2._MONTHLYCOSTFORECAST
_GETMONTHONMONTHCOSTFORECASTRESPONSE.fields_by_name['data'].message_type = api_dot_forecast__pb2._MONTHONMONTHCOSTFORECAST
_GETMONTHTODATECOSTFORECASTRESPONSE.fields_by_name['data'].message_type = api_dot_forecast__pb2._MONTHTODATECOSTFORECAST
_GETACCOUNTBUDGETRESPONSE.fields_by_name['data'].message_type = api_dot_budget__pb2._BUDGET
_CREATEACCOUNTBUDGETREQUEST.fields_by_name['data'].message_type = api_dot_budget__pb2._BUDGET
_UPDATEACCOUNTBUDGETREQUEST.fields_by_name['data'].message_type = api_dot_budget__pb2._BUDGET
_GETRECOMMENDATIONSREQUEST.fields_by_name['awsOptions'].message_type = _GETRECOMMENDATIONSREQUESTAWSOPTIONS
_GETRECOMMENDATIONSRESPONSE.fields_by_name['awsRecommendations'].message_type = api_dot_aws_dot_recommendation__pb2._AWSRECOMMENDATIONS
_GETCOSTREDUCTIONRESPONSE.fields_by_name['awsCostReductions'].message_type = api_dot_aws_dot_reduction__pb2._AWSCOSTREDUCTIONS
DESCRIPTOR.message_types_by_name['ListPayerAccountsRequest'] = _LISTPAYERACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['GetPayerAccountRequest'] = _GETPAYERACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['GetPayerAccountImportHistoryRequest'] = _GETPAYERACCOUNTIMPORTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['GetPayerAccountImportHistoryResponse'] = _GETPAYERACCOUNTIMPORTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CreatePayerAccountRequestAwsOptions'] = _CREATEPAYERACCOUNTREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['CreatePayerAccountRequest'] = _CREATEPAYERACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeletePayerAccountRequest'] = _DELETEPAYERACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ListAccountsRequest'] = _LISTACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['GetAccountRequest'] = _GETACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CreateAccountRequestAwsOptions'] = _CREATEACCOUNTREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['CreateAccountRequest'] = _CREATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccountRequest'] = _DELETEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['GetCalculatorStatusRequest'] = _GETCALCULATORSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetCalculatorStatusResponse'] = _GETCALCULATORSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetCalculatorConfigRequest'] = _GETCALCULATORCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetCalculatorConfigResponse'] = _GETCALCULATORCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ImportCurFilesRequest'] = _IMPORTCURFILESREQUEST
DESCRIPTOR.message_types_by_name['CostItem'] = _COSTITEM
DESCRIPTOR.message_types_by_name['CalculateCostsRequestAwsOptions'] = _CALCULATECOSTSREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['CalculateCostsRequest'] = _CALCULATECOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListCalculationsHistoryRequest'] = _LISTCALCULATIONSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ListCalculationsHistoryAwsResponse'] = _LISTCALCULATIONSHISTORYAWSRESPONSE
DESCRIPTOR.message_types_by_name['ListCalculationsHistoryResponse'] = _LISTCALCULATIONSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['ReadCostsRequestAwsOptionsFilters'] = _READCOSTSREQUESTAWSOPTIONSFILTERS
DESCRIPTOR.message_types_by_name['ReadCostsRequestAwsOptions'] = _READCOSTSREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['ReadCostsRequest'] = _READCOSTSREQUEST
DESCRIPTOR.message_types_by_name['ReadAdjustmentsRequestAwsOptions'] = _READADJUSTMENTSREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['ReadAdjustmentsRequest'] = _READADJUSTMENTSREQUEST
DESCRIPTOR.message_types_by_name['ReadTagCostsRequestAwsOptions'] = _READTAGCOSTSREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['ReadTagCostsRequest'] = _READTAGCOSTSREQUEST
DESCRIPTOR.message_types_by_name['ReadNonTagCostsRequest'] = _READNONTAGCOSTSREQUEST
DESCRIPTOR.message_types_by_name['GetForecastsRequest'] = _GETFORECASTSREQUEST
DESCRIPTOR.message_types_by_name['GetForecastsResponse'] = _GETFORECASTSRESPONSE
DESCRIPTOR.message_types_by_name['GetMonthlyCostForecastRequest'] = _GETMONTHLYCOSTFORECASTREQUEST
DESCRIPTOR.message_types_by_name['GetMonthlyCostForecastResponse'] = _GETMONTHLYCOSTFORECASTRESPONSE
DESCRIPTOR.message_types_by_name['GetMonthOnMonthCostForecastRequest'] = _GETMONTHONMONTHCOSTFORECASTREQUEST
DESCRIPTOR.message_types_by_name['GetMonthOnMonthCostForecastResponse'] = _GETMONTHONMONTHCOSTFORECASTRESPONSE
DESCRIPTOR.message_types_by_name['GetMonthToDateCostForecastRequest'] = _GETMONTHTODATECOSTFORECASTREQUEST
DESCRIPTOR.message_types_by_name['GetMonthToDateCostForecastResponse'] = _GETMONTHTODATECOSTFORECASTRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountBudgetRequest'] = _GETACCOUNTBUDGETREQUEST
DESCRIPTOR.message_types_by_name['GetAccountBudgetResponse'] = _GETACCOUNTBUDGETRESPONSE
DESCRIPTOR.message_types_by_name['CreateAccountBudgetRequest'] = _CREATEACCOUNTBUDGETREQUEST
DESCRIPTOR.message_types_by_name['CreateAccountBudgetResponse'] = _CREATEACCOUNTBUDGETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAccountBudgetRequest'] = _UPDATEACCOUNTBUDGETREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccountBudgetRequest'] = _DELETEACCOUNTBUDGETREQUEST
DESCRIPTOR.message_types_by_name['GetRecommendationsRequestAwsOptions'] = _GETRECOMMENDATIONSREQUESTAWSOPTIONS
DESCRIPTOR.message_types_by_name['GetRecommendationsRequest'] = _GETRECOMMENDATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetRecommendationsResponse'] = _GETRECOMMENDATIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetCostReductionRequest'] = _GETCOSTREDUCTIONREQUEST
DESCRIPTOR.message_types_by_name['GetCostReductionResponse'] = _GETCOSTREDUCTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPayerAccountsRequest = _reflection.GeneratedProtocolMessageType('ListPayerAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPAYERACCOUNTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ListPayerAccountsRequest)
  })
_sym_db.RegisterMessage(ListPayerAccountsRequest)

GetPayerAccountRequest = _reflection.GeneratedProtocolMessageType('GetPayerAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPAYERACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetPayerAccountRequest)
  })
_sym_db.RegisterMessage(GetPayerAccountRequest)

GetPayerAccountImportHistoryRequest = _reflection.GeneratedProtocolMessageType('GetPayerAccountImportHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPAYERACCOUNTIMPORTHISTORYREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetPayerAccountImportHistoryRequest)
  })
_sym_db.RegisterMessage(GetPayerAccountImportHistoryRequest)

GetPayerAccountImportHistoryResponse = _reflection.GeneratedProtocolMessageType('GetPayerAccountImportHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPAYERACCOUNTIMPORTHISTORYRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetPayerAccountImportHistoryResponse)
  })
_sym_db.RegisterMessage(GetPayerAccountImportHistoryResponse)

CreatePayerAccountRequestAwsOptions = _reflection.GeneratedProtocolMessageType('CreatePayerAccountRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPAYERACCOUNTREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreatePayerAccountRequestAwsOptions)
  })
_sym_db.RegisterMessage(CreatePayerAccountRequestAwsOptions)

CreatePayerAccountRequest = _reflection.GeneratedProtocolMessageType('CreatePayerAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPAYERACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreatePayerAccountRequest)
  })
_sym_db.RegisterMessage(CreatePayerAccountRequest)

DeletePayerAccountRequest = _reflection.GeneratedProtocolMessageType('DeletePayerAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPAYERACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.DeletePayerAccountRequest)
  })
_sym_db.RegisterMessage(DeletePayerAccountRequest)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

CreateAccountRequestAwsOptions = _reflection.GeneratedProtocolMessageType('CreateAccountRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreateAccountRequestAwsOptions)
  })
_sym_db.RegisterMessage(CreateAccountRequestAwsOptions)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)

GetCalculatorStatusRequest = _reflection.GeneratedProtocolMessageType('GetCalculatorStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCALCULATORSTATUSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCalculatorStatusRequest)
  })
_sym_db.RegisterMessage(GetCalculatorStatusRequest)

GetCalculatorStatusResponse = _reflection.GeneratedProtocolMessageType('GetCalculatorStatusResponse', (_message.Message,), {

  'AwsStatus' : _reflection.GeneratedProtocolMessageType('AwsStatus', (_message.Message,), {
    'DESCRIPTOR' : _GETCALCULATORSTATUSRESPONSE_AWSSTATUS,
    '__module__' : 'cost.v1.cost_pb2'
    # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCalculatorStatusResponse.AwsStatus)
    })
  ,
  'DESCRIPTOR' : _GETCALCULATORSTATUSRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCalculatorStatusResponse)
  })
_sym_db.RegisterMessage(GetCalculatorStatusResponse)
_sym_db.RegisterMessage(GetCalculatorStatusResponse.AwsStatus)

GetCalculatorConfigRequest = _reflection.GeneratedProtocolMessageType('GetCalculatorConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCALCULATORCONFIGREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCalculatorConfigRequest)
  })
_sym_db.RegisterMessage(GetCalculatorConfigRequest)

GetCalculatorConfigResponse = _reflection.GeneratedProtocolMessageType('GetCalculatorConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCALCULATORCONFIGRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCalculatorConfigResponse)
  })
_sym_db.RegisterMessage(GetCalculatorConfigResponse)

ImportCurFilesRequest = _reflection.GeneratedProtocolMessageType('ImportCurFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTCURFILESREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ImportCurFilesRequest)
  })
_sym_db.RegisterMessage(ImportCurFilesRequest)

CostItem = _reflection.GeneratedProtocolMessageType('CostItem', (_message.Message,), {
  'DESCRIPTOR' : _COSTITEM,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CostItem)
  })
_sym_db.RegisterMessage(CostItem)

CalculateCostsRequestAwsOptions = _reflection.GeneratedProtocolMessageType('CalculateCostsRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATECOSTSREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CalculateCostsRequestAwsOptions)
  })
_sym_db.RegisterMessage(CalculateCostsRequestAwsOptions)

CalculateCostsRequest = _reflection.GeneratedProtocolMessageType('CalculateCostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATECOSTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CalculateCostsRequest)
  })
_sym_db.RegisterMessage(CalculateCostsRequest)

ListCalculationsHistoryRequest = _reflection.GeneratedProtocolMessageType('ListCalculationsHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCALCULATIONSHISTORYREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ListCalculationsHistoryRequest)
  })
_sym_db.RegisterMessage(ListCalculationsHistoryRequest)

ListCalculationsHistoryAwsResponse = _reflection.GeneratedProtocolMessageType('ListCalculationsHistoryAwsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCALCULATIONSHISTORYAWSRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ListCalculationsHistoryAwsResponse)
  })
_sym_db.RegisterMessage(ListCalculationsHistoryAwsResponse)

ListCalculationsHistoryResponse = _reflection.GeneratedProtocolMessageType('ListCalculationsHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCALCULATIONSHISTORYRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ListCalculationsHistoryResponse)
  })
_sym_db.RegisterMessage(ListCalculationsHistoryResponse)

ReadCostsRequestAwsOptionsFilters = _reflection.GeneratedProtocolMessageType('ReadCostsRequestAwsOptionsFilters', (_message.Message,), {

  'AndFiltersEntry' : _reflection.GeneratedProtocolMessageType('AndFiltersEntry', (_message.Message,), {
    'DESCRIPTOR' : _READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY,
    '__module__' : 'cost.v1.cost_pb2'
    # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters.AndFiltersEntry)
    })
  ,
  'DESCRIPTOR' : _READCOSTSREQUESTAWSOPTIONSFILTERS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadCostsRequestAwsOptionsFilters)
  })
_sym_db.RegisterMessage(ReadCostsRequestAwsOptionsFilters)
_sym_db.RegisterMessage(ReadCostsRequestAwsOptionsFilters.AndFiltersEntry)

ReadCostsRequestAwsOptions = _reflection.GeneratedProtocolMessageType('ReadCostsRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _READCOSTSREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadCostsRequestAwsOptions)
  })
_sym_db.RegisterMessage(ReadCostsRequestAwsOptions)

ReadCostsRequest = _reflection.GeneratedProtocolMessageType('ReadCostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READCOSTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadCostsRequest)
  })
_sym_db.RegisterMessage(ReadCostsRequest)

ReadAdjustmentsRequestAwsOptions = _reflection.GeneratedProtocolMessageType('ReadAdjustmentsRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _READADJUSTMENTSREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadAdjustmentsRequestAwsOptions)
  })
_sym_db.RegisterMessage(ReadAdjustmentsRequestAwsOptions)

ReadAdjustmentsRequest = _reflection.GeneratedProtocolMessageType('ReadAdjustmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READADJUSTMENTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadAdjustmentsRequest)
  })
_sym_db.RegisterMessage(ReadAdjustmentsRequest)

ReadTagCostsRequestAwsOptions = _reflection.GeneratedProtocolMessageType('ReadTagCostsRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _READTAGCOSTSREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadTagCostsRequestAwsOptions)
  })
_sym_db.RegisterMessage(ReadTagCostsRequestAwsOptions)

ReadTagCostsRequest = _reflection.GeneratedProtocolMessageType('ReadTagCostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READTAGCOSTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadTagCostsRequest)
  })
_sym_db.RegisterMessage(ReadTagCostsRequest)

ReadNonTagCostsRequest = _reflection.GeneratedProtocolMessageType('ReadNonTagCostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READNONTAGCOSTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.ReadNonTagCostsRequest)
  })
_sym_db.RegisterMessage(ReadNonTagCostsRequest)

GetForecastsRequest = _reflection.GeneratedProtocolMessageType('GetForecastsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFORECASTSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetForecastsRequest)
  })
_sym_db.RegisterMessage(GetForecastsRequest)

GetForecastsResponse = _reflection.GeneratedProtocolMessageType('GetForecastsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFORECASTSRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetForecastsResponse)
  })
_sym_db.RegisterMessage(GetForecastsResponse)

GetMonthlyCostForecastRequest = _reflection.GeneratedProtocolMessageType('GetMonthlyCostForecastRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHLYCOSTFORECASTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthlyCostForecastRequest)
  })
_sym_db.RegisterMessage(GetMonthlyCostForecastRequest)

GetMonthlyCostForecastResponse = _reflection.GeneratedProtocolMessageType('GetMonthlyCostForecastResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHLYCOSTFORECASTRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthlyCostForecastResponse)
  })
_sym_db.RegisterMessage(GetMonthlyCostForecastResponse)

GetMonthOnMonthCostForecastRequest = _reflection.GeneratedProtocolMessageType('GetMonthOnMonthCostForecastRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHONMONTHCOSTFORECASTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthOnMonthCostForecastRequest)
  })
_sym_db.RegisterMessage(GetMonthOnMonthCostForecastRequest)

GetMonthOnMonthCostForecastResponse = _reflection.GeneratedProtocolMessageType('GetMonthOnMonthCostForecastResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHONMONTHCOSTFORECASTRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthOnMonthCostForecastResponse)
  })
_sym_db.RegisterMessage(GetMonthOnMonthCostForecastResponse)

GetMonthToDateCostForecastRequest = _reflection.GeneratedProtocolMessageType('GetMonthToDateCostForecastRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHTODATECOSTFORECASTREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthToDateCostForecastRequest)
  })
_sym_db.RegisterMessage(GetMonthToDateCostForecastRequest)

GetMonthToDateCostForecastResponse = _reflection.GeneratedProtocolMessageType('GetMonthToDateCostForecastResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMONTHTODATECOSTFORECASTRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetMonthToDateCostForecastResponse)
  })
_sym_db.RegisterMessage(GetMonthToDateCostForecastResponse)

GetAccountBudgetRequest = _reflection.GeneratedProtocolMessageType('GetAccountBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTBUDGETREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetAccountBudgetRequest)
  })
_sym_db.RegisterMessage(GetAccountBudgetRequest)

GetAccountBudgetResponse = _reflection.GeneratedProtocolMessageType('GetAccountBudgetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTBUDGETRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetAccountBudgetResponse)
  })
_sym_db.RegisterMessage(GetAccountBudgetResponse)

CreateAccountBudgetRequest = _reflection.GeneratedProtocolMessageType('CreateAccountBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTBUDGETREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreateAccountBudgetRequest)
  })
_sym_db.RegisterMessage(CreateAccountBudgetRequest)

CreateAccountBudgetResponse = _reflection.GeneratedProtocolMessageType('CreateAccountBudgetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTBUDGETRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.CreateAccountBudgetResponse)
  })
_sym_db.RegisterMessage(CreateAccountBudgetResponse)

UpdateAccountBudgetRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTBUDGETREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.UpdateAccountBudgetRequest)
  })
_sym_db.RegisterMessage(UpdateAccountBudgetRequest)

DeleteAccountBudgetRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTBUDGETREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.DeleteAccountBudgetRequest)
  })
_sym_db.RegisterMessage(DeleteAccountBudgetRequest)

GetRecommendationsRequestAwsOptions = _reflection.GeneratedProtocolMessageType('GetRecommendationsRequestAwsOptions', (_message.Message,), {
  'DESCRIPTOR' : _GETRECOMMENDATIONSREQUESTAWSOPTIONS,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetRecommendationsRequestAwsOptions)
  })
_sym_db.RegisterMessage(GetRecommendationsRequestAwsOptions)

GetRecommendationsRequest = _reflection.GeneratedProtocolMessageType('GetRecommendationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECOMMENDATIONSREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetRecommendationsRequest)
  })
_sym_db.RegisterMessage(GetRecommendationsRequest)

GetRecommendationsResponse = _reflection.GeneratedProtocolMessageType('GetRecommendationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECOMMENDATIONSRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetRecommendationsResponse)
  })
_sym_db.RegisterMessage(GetRecommendationsResponse)

GetCostReductionRequest = _reflection.GeneratedProtocolMessageType('GetCostReductionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOSTREDUCTIONREQUEST,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCostReductionRequest)
  })
_sym_db.RegisterMessage(GetCostReductionRequest)

GetCostReductionResponse = _reflection.GeneratedProtocolMessageType('GetCostReductionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOSTREDUCTIONRESPONSE,
  '__module__' : 'cost.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.cost.v1.GetCostReductionResponse)
  })
_sym_db.RegisterMessage(GetCostReductionResponse)


DESCRIPTOR._options = None
_READCOSTSREQUESTAWSOPTIONSFILTERS_ANDFILTERSENTRY._options = None

_COST = _descriptor.ServiceDescriptor(
  name='Cost',
  full_name='blueapi.cost.v1.Cost',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\220\001\022@(BETA) Cost API. Base URL: https://api.alphaus.cloud/m/blue/cost\032L\n\022Service definition\0226https://github.com/alphauslabs/blueapi/tree/main/cost/',
  create_key=_descriptor._internal_create_key,
  serialized_start=5594,
  serialized_end=9673,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPayerAccounts',
    full_name='blueapi.cost.v1.Cost.ListPayerAccounts',
    index=0,
    containing_service=None,
    input_type=_LISTPAYERACCOUNTSREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/{vendor}/payers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPayerAccount',
    full_name='blueapi.cost.v1.Cost.GetPayerAccount',
    index=1,
    containing_service=None,
    input_type=_GETPAYERACCOUNTREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\032\022\030/v1/{vendor}/payers/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPayerAccountImportHistory',
    full_name='blueapi.cost.v1.Cost.GetPayerAccountImportHistory',
    index=2,
    containing_service=None,
    input_type=_GETPAYERACCOUNTIMPORTHISTORYREQUEST,
    output_type=_GETPAYERACCOUNTIMPORTHISTORYRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/v1/{vendor}/payers/{id}/importhistory',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePayerAccount',
    full_name='blueapi.cost.v1.Cost.CreatePayerAccount',
    index=3,
    containing_service=None,
    input_type=_CREATEPAYERACCOUNTREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\030\"\023/v1/{vendor}/payers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePayerAccount',
    full_name='blueapi.cost.v1.Cost.DeletePayerAccount',
    index=4,
    containing_service=None,
    input_type=_DELETEPAYERACCOUNTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\032*\030/v1/{vendor}/payers/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccounts',
    full_name='blueapi.cost.v1.Cost.ListAccounts',
    index=5,
    containing_service=None,
    input_type=_LISTACCOUNTSREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/{vendor}/accounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccount',
    full_name='blueapi.cost.v1.Cost.GetAccount',
    index=6,
    containing_service=None,
    input_type=_GETACCOUNTREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/{vendor}/accounts/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccount',
    full_name='blueapi.cost.v1.Cost.CreateAccount',
    index=7,
    containing_service=None,
    input_type=_CREATEACCOUNTREQUEST,
    output_type=api_dot_account__pb2._ACCOUNT,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/{vendor}/accounts:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAccount',
    full_name='blueapi.cost.v1.Cost.DeleteAccount',
    index=8,
    containing_service=None,
    input_type=_DELETEACCOUNTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\034*\032/v1/{vendor}/accounts/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCalculatorStatus',
    full_name='blueapi.cost.v1.Cost.GetCalculatorStatus',
    index=9,
    containing_service=None,
    input_type=_GETCALCULATORSTATUSREQUEST,
    output_type=_GETCALCULATORSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1/{vendor}/calculator/status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCalculatorConfig',
    full_name='blueapi.cost.v1.Cost.GetCalculatorConfig',
    index=10,
    containing_service=None,
    input_type=_GETCALCULATORCONFIGREQUEST,
    output_type=_GETCALCULATORCONFIGRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1/{vendor}/calculator/config',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ImportCurFiles',
    full_name='blueapi.cost.v1.Cost.ImportCurFiles',
    index=11,
    containing_service=None,
    input_type=_IMPORTCURFILESREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/aws/cur:import:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CalculateCosts',
    full_name='blueapi.cost.v1.Cost.CalculateCosts',
    index=12,
    containing_service=None,
    input_type=_CALCULATECOSTSREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/{vendor}/costs:calculate:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCalculationsHistory',
    full_name='blueapi.cost.v1.Cost.ListCalculationsHistory',
    index=13,
    containing_service=None,
    input_type=_LISTCALCULATIONSHISTORYREQUEST,
    output_type=_LISTCALCULATIONSHISTORYRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/v1/{vendor}/calculations/history',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadCosts',
    full_name='blueapi.cost.v1.Cost.ReadCosts',
    index=14,
    containing_service=None,
    input_type=_READCOSTSREQUEST,
    output_type=_COSTITEM,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/{vendor}/costs:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadAdjustments',
    full_name='blueapi.cost.v1.Cost.ReadAdjustments',
    index=15,
    containing_service=None,
    input_type=_READADJUSTMENTSREQUEST,
    output_type=_COSTITEM,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/{vendor}/adjustments:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadTagCosts',
    full_name='blueapi.cost.v1.Cost.ReadTagCosts',
    index=16,
    containing_service=None,
    input_type=_READTAGCOSTSREQUEST,
    output_type=_COSTITEM,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/{vendor}/tagcosts:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadNonTagCosts',
    full_name='blueapi.cost.v1.Cost.ReadNonTagCosts',
    index=17,
    containing_service=None,
    input_type=_READNONTAGCOSTSREQUEST,
    output_type=_COSTITEM,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/{vendor}/nontagcosts:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetForecasts',
    full_name='blueapi.cost.v1.Cost.GetForecasts',
    index=18,
    containing_service=None,
    input_type=_GETFORECASTSREQUEST,
    output_type=_GETFORECASTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/{vendor}/forecasts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMonthlyCostForecast',
    full_name='blueapi.cost.v1.Cost.GetMonthlyCostForecast',
    index=19,
    containing_service=None,
    input_type=_GETMONTHLYCOSTFORECASTREQUEST,
    output_type=_GETMONTHLYCOSTFORECASTRESPONSE,
    serialized_options=b'\202\323\344\223\002-\022+/v1/{vendor}/forecasts/monthly/{level}/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMonthOnMonthCostForecast',
    full_name='blueapi.cost.v1.Cost.GetMonthOnMonthCostForecast',
    index=20,
    containing_service=None,
    input_type=_GETMONTHONMONTHCOSTFORECASTREQUEST,
    output_type=_GETMONTHONMONTHCOSTFORECASTRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/v1/{vendor}/forecasts/month-on-month/{level}/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMonthToDateCostForecast',
    full_name='blueapi.cost.v1.Cost.GetMonthToDateCostForecast',
    index=21,
    containing_service=None,
    input_type=_GETMONTHTODATECOSTFORECASTREQUEST,
    output_type=_GETMONTHTODATECOSTFORECASTRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/v1/{vendor}/forecasts/month-to-date/{level}/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountBudget',
    full_name='blueapi.cost.v1.Cost.GetAccountBudget',
    index=22,
    containing_service=None,
    input_type=_GETACCOUNTBUDGETREQUEST,
    output_type=_GETACCOUNTBUDGETRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /v1/{vendor}/budget/{level}/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccountBudget',
    full_name='blueapi.cost.v1.Cost.CreateAccountBudget',
    index=23,
    containing_service=None,
    input_type=_CREATEACCOUNTBUDGETREQUEST,
    output_type=_CREATEACCOUNTBUDGETRESPONSE,
    serialized_options=b'\202\323\344\223\002%\" /v1/{vendor}/budget/{level}/{id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccountBudget',
    full_name='blueapi.cost.v1.Cost.UpdateAccountBudget',
    index=24,
    containing_service=None,
    input_type=_UPDATEACCOUNTBUDGETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002#\032\036/v1/{vendor}/budget/{budgetId}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAccountBudget',
    full_name='blueapi.cost.v1.Cost.DeleteAccountBudget',
    index=25,
    containing_service=None,
    input_type=_DELETEACCOUNTBUDGETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002 *\036/v1/{vendor}/budget/{budgetId}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecommendations',
    full_name='blueapi.cost.v1.Cost.GetRecommendations',
    index=26,
    containing_service=None,
    input_type=_GETRECOMMENDATIONSREQUEST,
    output_type=_GETRECOMMENDATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002.\")/v1/{vendor}/recommendations/{orgId}:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCostReduction',
    full_name='blueapi.cost.v1.Cost.GetCostReduction',
    index=27,
    containing_service=None,
    input_type=_GETCOSTREDUCTIONREQUEST,
    output_type=_GETCOSTREDUCTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002(\"#/v1/{vendor}/reduction/{orgId}:read:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COST)

DESCRIPTOR.services_by_name['Cost'] = _COST

# @@protoc_insertion_point(module_scope)
